@@ -1,4 +1,4 @@
-__version__ = "0.9.3"
+__version__ = "0.9.8"
 
 __all__ = []
 
@@ -28,3 +28,13 @@ from matplotlib.pyplot import show,savefig
 
 mpl_imported=['show','savefig']
 __all__.extend(mpl_imported)
+
+# Register 'RGB' colormap in current session
+from matplotlib.colors import LinearSegmentedColormap as LSC
+import matplotlib.pyplot as plt, numpy as np
+RGB = LSC.from_list('RGB',[(0.9,0,0),(0.9,0.9,0),(0,0.9,0),(0,0.9,0.9),(0,0,0.9)])
+plt.register_cmap('RGB',RGB)
+
+# color_marices for quick_rgb_lines
+color_matrix = np.array([[0.5, 0, 0.5, 1],[0.5, 0.5, 0., 1],[0., 0.5, 0.5,0 ]])
+gray_matrix = np.array([[1,0,0,0],[0,1,0,1],[0,0,1,0]])
\ No newline at end of file
